@@ -1,5 +1,5 @@
 package CPAN::Upload::Tiny;
-$CPAN::Upload::Tiny::VERSION = '0.001';
+$CPAN::Upload::Tiny::VERSION = '0.002';
 use strict;
 use warnings;
 
@@ -96,13 +96,19 @@ CPAN::Upload::Tiny - A tiny CPAN uploader
 
 =head1 VERSION
 
-version 0.001
+version 0.002
+
+=head1 SYNOPSIS
+
+ use CPAN::Upload::Tiny;
+ my $upload = CPAN::Upload::Tiny->new_from_config($optional_file);
+ $upload->upload_file($filename);
 
 =head1 METHODS
 
 =head2 new($username, $password)
 
-This creates a new C<CPAN::Upload::Tiny> object. It requres a C<$username> and a C<$password>.
+This creates a new C<CPAN::Upload::Tiny> object. It requires a C<$username> and a C<$password>.
 
 =head2 new_from_config($filename)
 
@@ -112,6 +118,20 @@ This creates a new C<CPAN::Upload::Tiny> based on a F<.pause> configuration file
 
 This uploads the given file to PAUSE/CPAN.
 
+=head1 SEE ALSO
+
+=over 4
+
+=item * L<CPAN::Uploader|CPAN::Uploader>
+
+A heavier but more featureful CPAN uploader
+
+=item * L<Config::Identity|Config::Identity>
+
+This allows you to encrypt your configuration file.
+
+=back
+
 =head1 AUTHOR
 
 Leon Timmermans <leont@cpan.org>
